package config

import (
	"github.com/zeromicro/go-zero/core/stores/cache"
	"github.com/zeromicro/go-zero/rest"
)

type Config struct {
	rest.RestConf
	DataSource string
	CacheRedis cache.CacheConf
	JwtAuth    JwtAuth // JWT 鉴权相关配置
	VerifyCode VerifyCode
	Encrypt    Encrypt
	Alipay     AlipayConfig
	Wxpay      WxpayConfig
	Ali        AliConfig
	WestConfig WestConfig
}

// JwtAuth 用于 JWT 鉴权配置
type JwtAuth struct {
	AccessSecret string // JWT 密钥，用于签发 Token
	AccessExpire int64  // Token 过期时间，单位为秒
	RefreshAfter int64
}
type VerifyCode struct {
	AccessKeyID     string
	AccessKeySecret string
	EndpointURL     string
	SignName        string
	TemplateCode    string
	ValidTime       int
}
type Encrypt struct {
	SecretKey string
}

type AlipayConfig struct {
	AppID           string
	PrivateKey      string
	AlipayPublicKey string
	IsProduction    bool
	NotifyUrl       string
}
type WxpayConfig struct {
	AppID                      string
	MchID                      string
	MchCertificateSerialNumber string
	MchApiv3Key                string
	MchPrivateKeyPath          string
	NotifyUrl                  string
	RefundNotifyUrl            string
}
type AliConfig struct {
	Code string
}
type WestConfig struct {
	Url            string
	Key            string
	SecretId       string
	SecretSecondId string
}
